@@ -12,7 +12,9 @@ fn main() {
         Orientation,
     }
 
-    vviz::app::spawn(|mut manager: vviz::manager::Manager| {
+    let manipulation = Manipulation::Position;
+
+    vviz::app::spawn(move |mut manager: vviz::manager::Manager| {
         let w3d = manager.add_widget3("w3d".to_string());
 
         w3d.place_entity("cube".to_string(), vviz::entities::colored_cube(1.0));
@@ -20,8 +22,7 @@ fn main() {
 
         let mut ui_delta = manager.add_ranged_value("delta".to_string(), 0.0, (-1.0, 1.0));
         let mut ui_dim = manager.add_ranged_value("dimension".to_string(), 0, (0, 2));
-        let mut ui_manipulation =
-            manager.add_enum("manipulation".to_string(), Manipulation::Position);
+        let mut ui_manipulation = manager.add_enum("manipulation".to_string(), manipulation);
 
         loop {
             if ui_delta.get_new_value().is_some()
